"""
This type stub file was generated by pyright.
"""

import dataclasses
from enum import Enum
from typing import Tuple

"""Font definition module."""
def get_fontfile_tuple(path: str, md5_hash: str) -> Tuple[str, str, str]:
    """Convert provided path to local absolute path and download URL with MD5 info.

    This function takes a relative path to a font file and its MD5 hash, then constructs
    the absolute local path to the font file, the download URL, and returns them along
    with the MD5 hash.

    Args:
        path (str): The relative path to the font file.
        md5_hash (str): The MD5 hash of the font file.

    Returns:
        Tuple[str, str, str]: A tuple containing:
            - font_path (str): The local absolute path to the font file.
            - url (str): The download URL for the font file.
            - md5_hash (str): The MD5 hash of the font file.
    """
    ...

@dataclasses.dataclass
class FontFile:
    """A class representing a font file"""
    file: str
    @property
    def file(self) -> str:
        """Get the font file path.

        Returns:
            str: The path to the font file.
        """
        ...
    
    @file.setter
    def file(self, value: str) -> None:
        """Set the font file path.

        Validates that the provided path exists and is a valid file path. If not,
        raises an appropriate exception.

        Args:
            value (str): The path to the font file.

        Raises:
            ValueError: If the provided value is a property.
            FileNotFoundError: If the file does not exist at the specified path.
        """
        ...
    


class FontBase(Enum):
    """Base class of all font classes."""
    ...


class Font(FontBase):
    """Basic fonts."""
    SANSSERIF_LIGHT = ...
    SANSSERIF_REGULAR = ...
    SANSSERIF_BOLD = ...
    SERIF_LIGHT = ...
    SERIF_REGULAR = ...
    SERIF_BOLD = ...


class FontSansSerif(FontBase):
    """SansSerif fonts."""
    LATO_LIGHT = ...
    LATO_REGULAR = ...
    LATO_BOLD = ...
    MONTSERRAT_LIGHT = ...
    MONTSERRAT_REGULAR = ...
    MONTSERRAT_BOLD = ...
    OSWALD_LIGHT = ...
    OSWALD_REGULAR = ...
    OSWALD_BOLD = ...
    POPPINS_LIGHT = ...
    POPPINS_REGULAR = ...
    POPPINS_BOLD = ...
    RALEWAYS_LIGHT = ...
    RALEWAYS_REGULAR = ...
    RALEWAYS_BOLD = ...


class FontSerif(FontBase):
    """Serif fonts."""
    COURIER_REGULAR = ...
    COURIER_BOLD = ...
    MERRIWEATHER_LIGHT = ...
    MERRIWEATHER_REGULAR = ...
    MERRIWEATHER_BOLD = ...
    PLATYPI_LIGHT = ...
    PLATYPI_REGULAR = ...
    PLATYPI_BOLD = ...
    PLAYFAIRDISPLAY_REGULAR = ...
    PLAYFAIRDISPLAY_BOLD = ...


class FontMonoSpace(FontBase):
    """Mono space fonts."""
    ROBOTO_MONO_LIGHT = ...
    ROBOTO_MONO_REGULAR = ...
    ROBOTO_MONO_BOLD = ...
    COURIER_REGULAR = ...
    COURIER_BOLD = ...
    SOURCECODEPRO_LIGHT = ...
    SOURCECODEPRO_REGULAR = ...
    SOURCECODEPRO_BOLD = ...
    SOURCEHANCODEJP_LIGHT = ...
    SOURCEHANCODEJP_REGULAR = ...
    SOURCEHANCODEJP_BOLD = ...


class FontRoboto(FontBase):
    """Roboto fonts."""
    ROBOTO_LIGHT = ...
    ROBOTO_REGULAR = ...
    ROBOTO_BOLD = ...
    SERIF_LIGHT = ...
    SERIF_REGULAR = ...
    SERIF_BOLD = ...
    MONO_LIGHT = ...
    MONO_REGULAR = ...
    MONO_BOLD = ...
    CONDENSED_LIGHT = ...
    CONDENSED_REGULAR = ...
    CONDENSED_BOLD = ...
    SLAB_LIGHT = ...
    SLAB_REGULAR = ...
    SLAB_BOLD = ...


class FontSourceCode(FontBase):
    """Source code fonts."""
    ROBOTO_MONO = ...
    COURIER = ...
    SOURCECODEPRO = ...
    SOURCEHANCODEJP = ...


class FontArabic(FontBase):
    """Arabic fonts."""
    SANSSERIF_LIGHT = ...
    SANSSERIF_REGULAR = ...
    SANSSERIF_BOLD = ...
    KUFI_LIGHT = ...
    KUFI_REGULAR = ...
    KUFI_BOLD = ...
    NASKH_REGULAR = ...
    NASKH_BOLD = ...


class FontBrahmic(FontBase):
    """Brahmic fonts."""
    BENGALI_SANSSERIF_LIGHT = ...
    BENGALI_SANSSERIF_REGULAR = ...
    BENGALI_SANSSERIF_BOLD = ...
    BENGALI_SERIF_LIGHT = ...
    BENGALI_SERIF_REGULAR = ...
    BENGALI_SERIF_BOLD = ...
    DEVANAGARI_SANSSERIF_LIGHT = ...
    DEVANAGARI_SANSSERIF_REGULAR = ...
    DEVANAGARI_SANSSERIF_BOLD = ...
    DEVANAGARI_SERIF_LIGHT = ...
    DEVANAGARI_SERIF_REGULAR = ...
    DEVANAGARI_SERIF_BOLD = ...
    TAMIL_SANSSERIF_LIGHT = ...
    TAMIL_SANSSERIF_REGULAR = ...
    TAMIL_SANSSERIF_BOLD = ...
    TAMIL_SERIF_LIGHT = ...
    TAMIL_SERIF_REGULAR = ...
    TAMIL_SERIF_BOLD = ...
    TELUGU_SANSSERIF_LIGHT = ...
    TELUGU_SANSSERIF_REGULAR = ...
    TELUGU_SANSSERIF_BOLD = ...
    TELUGU_SERIF_LIGHT = ...
    TELUGU_SERIF_REGULAR = ...
    TELUGU_SERIF_BOLD = ...


class FontChinese(FontBase):
    """Chinese fonts."""
    SIMPLIFIED_SANSSERIF_LIGHT = ...
    SIMPLIFIED_SANSSERIF_REGULAR = ...
    SIMPLIFIED_SANSSERIF_BOLD = ...
    SIMPLIFIED_SERIF_LIGHT = ...
    SIMPLIFIED_SERIF_REGULAR = ...
    SIMPLIFIED_SERIF_BOLD = ...
    TRADITIONAL_SANSSERIF_LIGHT = ...
    TRADITIONAL_SANSSERIF_REGULAR = ...
    TRADITIONAL_SANSSERIF_BOLD = ...
    TRADITIONAL_SERIF_LIGHT = ...
    TRADITIONAL_SERIF_REGULAR = ...
    TRADITIONAL_SERIF_BOLD = ...
    HONGKONG_SANSSERIF_LIGHT = ...
    HONGKONG_SANSSERIF_REGULAR = ...
    HONGKONG_SANSSERIF_BOLD = ...
    HONGKONG_SERIF_LIGHT = ...
    HONGKONG_SERIF_REGULAR = ...
    HONGKONG_SERIF_BOLD = ...


class FontJapanese(FontBase):
    """Japanese fonts."""
    SANSSERIF_LIGHT = ...
    SANSSERIF_REGULAR = ...
    SANSSERIF_BOLD = ...
    SERIF_LIGHT = ...
    SERIF_REGULAR = ...
    SERIF_BOLD = ...
    MPLUS1P_LIGHT = ...
    MPLUS1P_REGULAR = ...
    MPLUS1P_BOLD = ...
    MPLUSROUNDED1C_LIGHT = ...
    MPLUSROUNDED1C_REGULAR = ...
    MPLUSROUNDED1C_BOLD = ...
    SAWARABI_GOTHIC = ...
    SAWARABI_MINCHO = ...


class FontKorean(FontBase):
    """Korean fonts."""
    SANSSERIF_LIGHT = ...
    SANSSERIF_REGULAR = ...
    SANSSERIF_BOLD = ...
    SERIF_LIGHT = ...
    SERIF_REGULAR = ...
    SERIF_BOLD = ...


class FontThai(FontBase):
    """Thai fonts."""
    SANSSERIF_LIGHT = ...
    SANSSERIF_REGULAR = ...
    SANSSERIF_BOLD = ...
    SERIF_LIGHT = ...
    SERIF_REGULAR = ...
    SERIF_BOLD = ...


